@@ -22,7 +22,6 @@
 #include <QCommandLineOption>
 #include <QCommandLineParser>
 #include <QFile>
-#include <QDebug>
 
 #include <KAboutData>
 #include <KConfig>
@@ -30,6 +29,7 @@
 #include <KLocalizedString>
 #include <QStandardPaths>
 #include <QProcess>
+#include <QTextStream>
 
 #include <QDBusMessage>
 #include <QDBusConnection>
@@ -73,6 +73,16 @@ void resume()
     QDBusConnection::sessionBus().call(message);
 }
 
+void updateAllFolders()
+{
+    QDBusMessage message = QDBusMessage::createMethodCall(QLatin1String("org.kde.baloo"),
+                                                          QLatin1String("/indexer"),
+                                                          QLatin1String("org.kde.baloo"),
+                                                          QLatin1String("updateAllFolders"));
+    message.setArguments(QList<QVariant>() << false /*forced*/);
+    QDBusConnection::sessionBus().call(message);
+}
+
 int main(int argc, char* argv[])
 {
     KAboutData aboutData(QLatin1String("balooctl"), i18n("balooctl"), PROJECT_VERSION);
@@ -92,6 +102,7 @@ int main(int argc, char* argv[])
     parser.addPositionalArgument(QLatin1String("restart"), i18n("Restart the file indexer"));
     parser.addPositionalArgument(QLatin1String("suspend"), i18n("Suspend the file indexer"));
     parser.addPositionalArgument(QLatin1String("resume"), i18n("Resume the file indexer"));
+    parser.addPositionalArgument(QLatin1String("check"), i18n("Check for any unindexed files and index them"));
 
     parser.process(app);
     if (parser.positionalArguments().isEmpty()) {
@@ -213,6 +224,12 @@ int main(int argc, char* argv[])
         return 0;
     }
 
+    if (command == QStringLiteral("check")) {
+        updateAllFolders();
+        out << "Started search for unindexed files\n";
+        return 0;
+    }
+
     if (command == QStringLiteral("fileStatistics")) {
         const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/baloo/file/");
 
